@@ -63,5 +63,5 @@ func (widget *Widget) content() (string, string, bool) {
 }
 
 func (widget *Widget) display() {
-	widget.ScrollableWidget.Redraw(widget.content)
+	widget.Redraw(widget.content)
 }
