@@ -38,10 +38,7 @@ func (widget *Widget) fetchForAccount(account string, since string) (*Status, er
 		Timeout: time.Second * clientTimeoutSecs,
 	}
 
-	asTruncated := true
-	if since != "" {
-		asTruncated = false
-	}
+	asTruncated := since == ""
 
 	request, err := http.NewRequest(http.MethodGet, widget.fullURL(account, asTruncated), http.NoBody)
 	if err != nil {
