@@ -25,8 +25,8 @@ func NewSettingsFromYAML(name string, ymlConfig *config.Config, globalConfig *co
 		Common: cfg.NewCommonSettingsFromModule(name, defaultTitle, defaultFocusable, ymlConfig, globalConfig),
 	}
 
-	settings.colors.label = ymlConfig.UString("colors.label", "green")
-	settings.colors.text = ymlConfig.UString("colors.text", "white")
+	settings.label = ymlConfig.UString("colors.label", "green")
+	settings.text = ymlConfig.UString("colors.text", "white")
 
 	return &settings
 }
