@@ -1,7 +1,7 @@
 package twitter
 
 import (
-	"github.com/gdamore/tcell"
+	"github.com/gdamore/tcell/v2"
 	"github.com/wtfutil/wtf/utils"
 )
 
